Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/applicant.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/applicant.py	(revision 7269)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/applicant.py	(revision 7270)
@@ -91,5 +91,5 @@
     access_code = index.Field(attribute='access_code')
     applicant_id = index.Field(attribute='applicant_id')
-    reg_no = index.Field(attribute='reg_no')
+    reg_number = index.Field(attribute='reg_number')
 
 class ApplicantFactory(grok.GlobalUtility):
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/batching.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/batching.py	(revision 7269)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/batching.py	(revision 7270)
@@ -88,12 +88,12 @@
     def available_fields(self):
         return sorted(list(set(
-            ['application_number','reg_no'] + getFields(
+            ['application_number','reg_number'] + getFields(
                 self.iface).keys())))
 
     def checkHeaders(self, headerfields, mode='create'):
-        if not 'reg_no' in headerfields and not 'application_number' \
+        if not 'reg_number' in headerfields and not 'application_number' \
             in headerfields:
             raise FatalCSVError(
-                "Need at least columns application_number or reg_no ")
+                "Need at least columns application_number or reg_number ")
         if mode == 'create':
             for field in self.required_fields:
@@ -114,6 +114,6 @@
         if row.get('application_number',None):
             return 'application_number'
-        elif 'reg_no' in row.keys() and row['reg_no']:
-            return 'reg_no'
+        elif 'reg_number' in row.keys() and row['reg_number']:
+            return 'reg_number'
         else:
             return None
@@ -135,9 +135,9 @@
                 applicant = parent[row['application_number']]
                 return applicant
-        elif self.getLocator(row) == 'reg_no':
-            reg_no = row['reg_no']
+        elif self.getLocator(row) == 'reg_number':
+            reg_number = row['reg_number']
             cat = queryUtility(ICatalog, name='applicants_catalog')
             results = list(
-                cat.searchResults(reg_no=(reg_no, reg_no)))
+                cat.searchResults(reg_number=(reg_number, reg_number)))
             if results:
                 return results[0]
@@ -167,5 +167,5 @@
         for num, field in enumerate(headerfields):
             if field not in ['container_code',
-                'application_number', 'reg_no'] and mode == 'remove':
+                'application_number', 'reg_number'] and mode == 'remove':
                 continue
             if field == u'--IGNORE--':
@@ -179,5 +179,5 @@
         """
         if mode in ['update', 'remove']:
-            if self.getLocator(row) == 'reg_no':
+            if self.getLocator(row) == 'reg_number':
                 iface = IApplicantUpdateByRegNo
         else:
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser.py	(revision 7269)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser.py	(revision 7270)
@@ -931,5 +931,5 @@
     form_fields = grok.AutoFields(IApplicantEdit).omit(
         'locked', 'course_admitted', 'student_id',
-        'screening_score', 'applicant_id', 'reg_no'
+        'screening_score', 'applicant_id', 'reg_number'
         )
     form_fields['date_of_birth'].custom_widget = FriendlyDateWidget('le-year')
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/sample_applicant_data.csv
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/sample_applicant_data.csv	(revision 7269)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/sample_applicant_data.csv	(revision 7270)
@@ -1,3 +1,3 @@
-container_code,reg_no,firstname,lastname,date_of_birth,email,course1
+container_code,reg_number,firstname,lastname,date_of_birth,email,course1
 dp2011,1001,Aaren,Pieri,1990-01-02,xx@yy.zz,CERT1
 dp2011,1002,Aaren,Finau,1990-01-03,xx@yy.zz,CERT1
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/sample_applicant_data_update.csv
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/sample_applicant_data_update.csv	(revision 7269)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/sample_applicant_data_update.csv	(revision 7270)
@@ -1,3 +1,3 @@
-container_code,reg_no,firstname
+container_code,reg_number,firstname
 dp2011,1001,Aaren
 dp2011,1002,Alfons
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/interfaces.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/interfaces.py	(revision 7269)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/interfaces.py	(revision 7270)
@@ -53,5 +53,5 @@
     implements(ISource)
     cat_name = 'applicants_catalog'
-    field_name = 'reg_no'
+    field_name = 'reg_number'
     validation_error = RegNumInSource
     def __init__(self, context):
@@ -298,5 +298,5 @@
         readonly = False,
         )
-    reg_no = TextLineChoice(
+    reg_number = TextLineChoice(
         title = u'JAMB Registration Number',
         readonly = False,
@@ -446,8 +446,8 @@
     """Representation of an applicant.
 
     Skip regular reg_no validation if reg_no is used for finding
     the applicant object.
     """
-    reg_no = schema.TextLine(
+    reg_number = schema.TextLine(
         title = u'Registration Number',
         default = None,
@@ -446,8 +446,8 @@
     """Representation of an applicant.
 
-    Skip regular reg_no validation if reg_no is used for finding
+    Skip regular reg_number validation if reg_number is used for finding
     the applicant object.
     """
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_browser.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_browser.py	(revision 7269)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_browser.py	(revision 7270)
@@ -118,7 +118,7 @@
         # Add an applicant
         self.applicant = Applicant()
         # reg_no is the only field which has to be preset here
         # because managers are allowed to edit this required field
-        self.applicant.reg_no = u'1234'
+        self.applicant.reg_number = u'1234'
         app['applicants']['app2009'].addApplicant(self.applicant)
         IUserAccount(
@@ -118,7 +118,7 @@
         # Add an applicant
         self.applicant = Applicant()
-        # reg_no is the only field which has to be preset here
+        # reg_number is the only field which has to be preset here
         # because managers are allowed to edit this required field
